@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef LOGACTIVITIESMAINWIDGET_H
-#define LOGACTIVITIESMAINWIDGET_H
+#pragma once
 
 #include <QWidget>
 
@@ -23,4 +22,3 @@ private:
     void slotAddLog();
 };
 
-#endif // LOGACTIVITIESMAINWIDGET_H
