@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MIGRATEFILEINFOTEST_H
-#define MIGRATEFILEINFOTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -22,4 +21,3 @@ private Q_SLOTS:
     void shouldBeEmpty();
 };
 
-#endif // MIGRATEFilEINFOTEST_H
