@@ -80,7 +80,7 @@ QByteArray ImapAclAttribute::type() const
 
 ImapAclAttribute *ImapAclAttribute::clone() const
 {
-    auto *attr = new ImapAclAttribute(d->mRights, d->mOldRights);
+    auto attr = new ImapAclAttribute(d->mRights, d->mOldRights);
     attr->setMyRights(d->mMyRights);
     return attr;
 }
@@ -125,7 +125,7 @@ QByteArray ImapAclAttribute::serialized() const
     return result;
 }
 
-static void fillRightsMap(const QList<QByteArray> &rights, QMap <QByteArray, KIMAP::Acl::Rights> &map)
+static void fillRightsMap(const QList<QByteArray> &rights, QMap<QByteArray, KIMAP::Acl::Rights> &map)
 {
     for (const QByteArray &right : rights) {
         const QByteArray trimmed = right.trimmed();
@@ -170,7 +170,5 @@ void ImapAclAttribute::deserialize(const QByteArray &data)
 
 bool ImapAclAttribute::operator==(const ImapAclAttribute &other) const
 {
-    return (oldRights() == other.oldRights())
-           && (rights() == other.rights())
-           && (myRights() == other.myRights());
+    return (oldRights() == other.oldRights()) && (rights() == other.rights()) && (myRights() == other.myRights());
 }
