@@ -109,10 +109,10 @@ void AddresseeLineEditPrivate::init()
         if (!mCompletionInitialized) {
             q->setCompletionObject(AddresseeLineEditManager::self()->completion(), false);
             connect(q, &KLineEdit::completion, this, &AddresseeLineEditPrivate::slotCompletion);
-            connect(q, &AddresseeLineEdit::returnPressed, this, &AddresseeLineEditPrivate::slotReturnPressed);
+            connect(q, &AddresseeLineEdit::returnKeyPressed, this, &AddresseeLineEditPrivate::slotReturnPressed);
 
             KCompletionBox *box = q->completionBox();
-            connect(box, qOverload<const QString &>(&KCompletionBox::activated), this, &AddresseeLineEditPrivate::slotPopupCompletion);
+            connect(box, &KCompletionBox::textActivated, this, &AddresseeLineEditPrivate::slotPopupCompletion);
             connect(box, &KCompletionBox::userCancelled, this, &AddresseeLineEditPrivate::slotUserCancelled);
             connect(AddresseeLineEditManager::self()->ldapTimer(), &QTimer::timeout, this, &AddresseeLineEditPrivate::slotStartLDAPLookup);
             connect(AddresseeLineEditManager::self()->ldapSearch(),
@@ -671,7 +671,7 @@ void AddresseeLineEditPrivate::slotAkonadiHandleItems(const Akonadi::Item::List
         if (sourceIndex.index == -1) {
             qCDebug(PIMCOMMONAKONADI_LOG) << "Fetching New collection: " << colId;
             // the collection isn't there, start the fetch job.
-            auto *collectionJob =
+            auto collectionJob =
                 new Akonadi::CollectionFetchJob(item.parentCollection(), Akonadi::CollectionFetchJob::Base, AddresseeLineEditManager::self()->akonadiSession());
             connect(collectionJob, &Akonadi::CollectionFetchJob::collectionsReceived, this, &AddresseeLineEditPrivate::slotAkonadiCollectionsReceived);
             /* we don't want to start multiple fetch jobs for the same collection,
