@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef ADDRESSEELINEEDITUTIL_H
-#define ADDRESSEELINEEDITUTIL_H
+#pragma once
 
 #include "pimcommonakonadi_export.h"
 #include <QString>
@@ -23,4 +22,3 @@ public:
 };
 }
 
-#endif // ADDRESSEELINEEDITUTIL_H
