@@ -24,9 +24,9 @@ IncidencesForWidgetTest::~IncidencesForWidgetTest()
 void IncidencesForWidgetTest::shouldHaveDefaultValue()
 {
     PimCommon::IncidencesForWidget contentType;
-    auto *label = contentType.findChild<QLabel *>(QStringLiteral("contentstypelabel"));
+    auto label = contentType.findChild<QLabel *>(QStringLiteral("contentstypelabel"));
     QVERIFY(label);
-    auto *combo = contentType.findChild<QComboBox *>(QStringLiteral("contentstypecombobox"));
+    auto combo = contentType.findChild<QComboBox *>(QStringLiteral("contentstypecombobox"));
     QVERIFY(combo);
     QVERIFY(combo->count() > 0);
     QCOMPARE(contentType.currentIndex(), 0);
@@ -35,7 +35,7 @@ void IncidencesForWidgetTest::shouldHaveDefaultValue()
 void IncidencesForWidgetTest::shouldChangeComboBoxIndex()
 {
     PimCommon::IncidencesForWidget contentType;
-    auto *combo = contentType.findChild<QComboBox *>(QStringLiteral("contentstypecombobox"));
+    auto combo = contentType.findChild<QComboBox *>(QStringLiteral("contentstypecombobox"));
     for (int i = 0; i < combo->count(); ++i) {
         contentType.setCurrentIndex(i);
         QCOMPARE(contentType.currentIndex(), i);
