@@ -3,8 +3,7 @@
    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef MESSAGECORE_ANNOTATIONDIALOG_H
-#define MESSAGECORE_ANNOTATIONDIALOG_H
+#pragma once
 
 #include "pimcommonakonadi_export.h"
 
@@ -52,4 +51,3 @@ private:
 };
 }
 
-#endif
